Enable checkstyle rule to catch variables that hide fields

Enable the checkstyle "HiddenFields" rule and fix any issues
that it detects.  Suppress these violations for parameters
to setters and constructors.

Added support for the checkstyle comment suppression module
// CHECKSTYLE:OFF and //CHECKSTYLE:ON are now
supported.

Suppressed HiddenField checks for net.onrc.onos.core.packet.*
rather than fix them.  These APIs are designed to
require formal parameters and local members having
the same name.

Change-Id: Ibc057603a934842d9c9b9b668f55bc5f5519e7f6
diff --git a/src/main/java/net/onrc/onos/core/linkdiscovery/internal/LinkDiscoveryManager.java b/src/main/java/net/onrc/onos/core/linkdiscovery/internal/LinkDiscoveryManager.java
index a764f1c..aeabb3a 100644
--- a/src/main/java/net/onrc/onos/core/linkdiscovery/internal/LinkDiscoveryManager.java
+++ b/src/main/java/net/onrc/onos/core/linkdiscovery/internal/LinkDiscoveryManager.java
@@ -1202,14 +1202,14 @@
     /**
      * Removes links from memory and storage.
      *
      * @param links The List of @LinkTuple to delete.
      */
-    protected void deleteLinks(List<Link> links, String reason) {
+    protected void deleteLinks(List<Link> linksToDelete, String reason) {
         NodePortTuple srcNpt, dstNpt;
 
         lock.writeLock().lock();
         try {
-            for (Link lt : links) {
+            for (Link lt : linksToDelete) {
                 srcNpt = new NodePortTuple(lt.getSrc(), lt.getSrcPort());
                 dstNpt = new NodePortTuple(lt.getDst(), lt.getDstPort());
@@ -1202,14 +1202,14 @@
      * Removes links from memory and storage.
      *
-     * @param links The List of @LinkTuple to delete.
+     * @param linksToDelete The List of @LinkTuple to delete.
      */